@@ -259,7 +259,7 @@ class Video:
             if stream:
                 r = requests.get(stream, stream=True)
 
-                with open(f"./download/{prefix}_{self._id}.mp3", "wb") as file:
+                with open(f"{prefix}_{self._id}.mp3", "wb") as file:
                     for chunk in r.iter_content(chunk_size=512):
                         if chunk:
                             file.write(chunk)
